"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.npmPackageUpdateAction = void 0;

var _toolLib = require("@kettil/tool-lib");

var _writeFile = require("../../cmd/writeFile");

var _packageLoad = require("./packageLoad");

const update = (config, values) => {
  if ((0, _toolLib.objectKeys)(values).length === 0) {
    return config;
  }

  return Object.assign((0, _toolLib.isObject)(config) ? config : {}, values);
};

const updatePeerDependencies = (config, values) => {
  const peerDependencies = {};
  const packages = config.devDependencies;

  if (!(0, _toolLib.isObject)(packages)) {
    throw new Error('In the package.json is the devDependencies empty');
  }

  values.forEach(value => {
    const version = packages[value];

    if (typeof version !== 'string') {
      throw new TypeError(`The peerDependency "${value}" is not found in the devDependencies`);
    }

    peerDependencies[value] = version;
  });
  return update(config.peerDependencies, peerDependencies);
};

const npmPackageUpdateAction = async (argv, {
  settings: {
    bin,
    scripts,
    peerDependencies,
    ...settings
  }
}) => {
  const {
    cwd,
    log
  } = argv;
  const config = await (0, _packageLoad.npmPackageLoadAction)(argv, {});

  if (!(0, _toolLib.isObject)(config)) {
    throw new TypeError('Package could not be interpreted as an object');
  }

  Object.assign(config, settings); // Update the bin part

  if (bin) {
    config.bin = update(config.bin, bin);
  } // Update the scripts part


  if (scripts) {
    config.scripts = update(config.scripts, scripts);
  } // Update the peerDependencies part


  if (peerDependencies && peerDependencies.length > 0) {
    config.peerDependencies = updatePeerDependencies(config, peerDependencies);
  }

  log.info('Extend the package.json');
  await (0, _writeFile.writeFile)((0, _packageLoad.getPackagePath)(cwd), config);
};

exports.npmPackageUpdateAction = npmPackageUpdateAction;