"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.semverAction = void 0;

var _toolLib = require("@kettil/tool-lib");

var _chalk = require("chalk");

var _semver = require("semver");

var _tableError = require("../../errors/tableError");

var _packageLoad = require("../npm/packageLoad");

const keys = ['dependencies', 'devDependencies'];

const getInaccurateVersions = packages => {
  if (!(0, _toolLib.isObject)(packages)) {
    return [];
  }

  return (0, _toolLib.objectEntries)(packages).filter(value => typeof value[1] === 'string').filter(([, version]) => !version.startsWith('file')).filter(([, version]) => !version.startsWith('http')).filter(([, version]) => !version.startsWith('git')).map(([name, version]) => {
    var _coerce;

    return [name, version, ((_coerce = (0, _semver.coerce)(version)) === null || _coerce === void 0 ? void 0 : _coerce.version) ?? 'could not be detected'];
  }).filter(([, version, result]) => version !== result);
};

const semverAction = async argv => {
  const packagesJson = await (0, _packageLoad.npmPackageLoadAction)(argv, {});

  if (!(0, _toolLib.isObject)(packagesJson)) {
    throw new Error('The package.json was not found');
  }

  const packages = keys.flatMap(key => getInaccurateVersions(packagesJson[key])).sort((0, _toolLib.compareTransformAsc)(([name]) => name)).map((value, index) => [`${index + 1}`, ...value]);

  if (packages.length > 0) {
    packages.unshift([(0, _chalk.red)('#'), (0, _chalk.red)('Package'), (0, _chalk.red)('Version'), (0, _chalk.red)('Expected')]);
    throw new _tableError.TableError('Packages with inaccurate version found', packages);
  }
};
/*
const p: Record<string, string> = {
  a: '1.0.0 - 2.9999.9999',
  b: '>=1.0.2 <2.1.2',
  c: '>1.0.2 <=2.3.4',
  d: '2.0.1',
  e: '<1.0.0 || >=2.3.1 <2.4.5 || >=2.5.2 <3.0.0',
  f: 'http://asdf.com/asdf.tar.gz',
  g: '~1.2',
  h: '~1.2.3',
  i: '2.x',
  j: '3.3.x',
  k: 'latest',
  l: 'file:../dyl',
  m: 'git://github.com/npm/cli.git',
};
*/


exports.semverAction = semverAction;