"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.analyseServices = exports.analyseTask = void 0;

var _actionConfigs = require("../../configs/actionConfigs");

var _eslint = require("../actions/tools/eslint");

var _prettier = require("../actions/tools/prettier");

var _tsc = require("../actions/tools/tsc");

var _spinner = require("../cli/spinner");

var _firstExistFileError = require("../errors/firstExistFileError");

var _getTypescriptConfigPath = require("../utils/getTypescriptConfigPath");

var _taskHook = require("../utils/taskHook");

const analyseServices = ['eslint', 'prettier', 'typescript'];
exports.analyseServices = analyseServices;

const isSelectedService = (value, service) => typeof value === 'undefined' || value === service;

const analyseTask = async (argv, {
  only,
  eslintFiles,
  prettierFiles
}) => {
  await (0, _taskHook.taskHook)(argv, {
    task: 'analyse',
    type: 'pre'
  });

  if (isSelectedService(only, 'prettier')) {
    const prettierOptions = {
      write: !argv.ci,
      extension: argv.ci ? _actionConfigs.prettierCiExtensions : undefined,
      files: prettierFiles
    };
    await (0, _spinner.spinnerAction)((0, _prettier.prettierAction)(argv, prettierOptions), 'Analyse: Prettier');
  }

  if (isSelectedService(only, 'eslint')) {
    const eslintOptions = {
      write: !argv.ci,
      files: eslintFiles
    };
    await (0, _spinner.spinnerAction)((0, _eslint.eslintAction)(argv, eslintOptions), 'Analyse: ESLint');
  }

  if (isSelectedService(only, 'typescript')) {
    try {
      await (0, _getTypescriptConfigPath.getTypescriptConfigPath)(argv.cwd, 'type-check');
      await (0, _spinner.spinnerAction)((0, _tsc.tscAction)(argv, {
        mode: 'type-check'
      }), 'Analyse: Typescript');
    } catch (error) {
      if (error instanceof _firstExistFileError.FirstExistFileError) {
        argv.log.info('Typing check is skipped (tsconfig.json was not found) ');
      } else {
        throw error;
      }
    }
  }

  await (0, _taskHook.taskHook)(argv, {
    task: 'analyse',
    type: 'post'
  });
};

exports.analyseTask = analyseTask;