"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buildTask = void 0;

var _packageLoad = require("../actions/npm/packageLoad");

var _babel = require("../actions/tools/babel");

var _tsc = require("../actions/tools/tsc");

var _spinner = require("../cli/spinner");

var _firstExistFileError = require("../errors/firstExistFileError");

var _getConfigPath = require("../utils/getConfigPath");

var _getTypescriptConfigPath = require("../utils/getTypescriptConfigPath");

var _taskHook = require("../utils/taskHook");

const buildTask = async argv => {
  await (0, _taskHook.taskHook)(argv, {
    task: 'build',
    type: 'pre'
  });
  const isPrivate = await (0, _packageLoad.npmPackageLoadAction)(argv, {
    key: 'private'
  });

  if (isPrivate !== true) {
    try {
      await (0, _getTypescriptConfigPath.getTypescriptConfigPath)(argv.cwd, 'type-create');
      await (0, _spinner.spinnerAction)((0, _tsc.tscAction)(argv, {
        mode: 'type-create'
      }), 'Build: Typescript');
    } catch (error) {
      if (!(error instanceof _firstExistFileError.FirstExistFileError)) {
        throw error;
      }
    }
  }

  try {
    await (0, _getConfigPath.getBabelConfigPath)({
      cwd: argv.cwd
    });
    await (0, _spinner.spinnerAction)((0, _babel.babelAction)(argv), 'Build: Babel');
  } catch (error) {
    if (!(error instanceof _firstExistFileError.FirstExistFileError)) {
      throw error;
    }
  }

  await (0, _taskHook.taskHook)(argv, {
    task: 'build',
    type: 'post'
  });
};

exports.buildTask = buildTask;