"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.depsTask = void 0;

var _toolLib = require("@kettil/tool-lib");

var _depcheck = require("../actions/tools/depcheck");

var _semver = require("../actions/tools/semver");

var _config = require("../cli/config");

var _spinner = require("../cli/spinner");

var _dependencyError = require("../errors/dependencyError");

var _taskHook = require("../utils/taskHook");

const depsTask = async argv => {
  const configIgnorePackages = await (0, _config.getConfig)(argv.cwd, 'deps.ignore.packages');
  const ignorePackages = (0, _toolLib.isArray)(configIgnorePackages) ? configIgnorePackages.filter(v => typeof v === 'string') : [];
  await (0, _taskHook.taskHook)(argv, {
    task: 'deps',
    type: 'pre'
  });

  try {
    await (0, _spinner.spinnerAction)((0, _depcheck.depcheckAction)(argv, ignorePackages), 'Dependency verification');
  } catch (error) {
    if (!(error instanceof _dependencyError.DependencyError)) {
      throw error;
    }

    argv.log.log(error.list);
  }

  await (0, _spinner.spinnerAction)((0, _semver.semverAction)(argv), 'Semver check');
  await (0, _taskHook.taskHook)(argv, {
    task: 'deps',
    type: 'post'
  });
};

exports.depsTask = depsTask;