"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initTask = void 0;

var _path = require("path");

var _add = require("../actions/git/add");

var _commit = require("../actions/git/commit");

var _init = require("../actions/git/init");

var _file = require("../actions/node/file");

var _folder = require("../actions/node/folder");

var _template = require("../actions/node/template");

var _init2 = require("../actions/npm/init");

var _install = require("../actions/npm/install");

var _packageLoad = require("../actions/npm/packageLoad");

var _packageUpdate = require("../actions/npm/packageUpdate");

var _spinner = require("../cli/spinner");

var _access = require("../cmd/access");

var _exec = require("../cmd/exec");

var _getInitTaskSettings = require("../utils/getInitTaskSettings");

var _getInitTaskTemplateVariables = require("../utils/getInitTaskTemplateVariables");

/* eslint-disable import/max-dependencies */
const initTask = async (argv, props) => {
  const hasGitFolder = await (0, _access.access)((0, _path.join)(argv.cwd, '.git'));
  const settings = (0, _getInitTaskSettings.getInitTaskSettings)(props); // npm init

  await (0, _spinner.spinnerAction)((0, _init2.npmInitAction)(argv, {
    settings: settings.packageInit
  }), 'Create the package.json');
  const packageName = await (0, _packageLoad.npmPackageLoadAction)(argv, {
    key: 'name'
  });

  if (typeof packageName !== 'string') {
    throw new TypeError('Package name could not be read');
  }

  if (props.cli) {
    settings.packageBin[packageName] = 'build/bin/index.js';
  } // git init


  await (0, _spinner.spinnerAction)((0, _init.gitInitAction)(argv), 'Create the git repository'); // create folders and files

  await (0, _spinner.spinnerAction)(Promise.all(settings.folders.map(folder => (0, _folder.nodeFolderAction)(argv, {
    folder
  }))), 'Create the project folders');
  await (0, _spinner.spinnerAction)(Promise.all(settings.files.map(file => (0, _file.nodeFileAction)(argv, {
    file
  }))), 'Create the project files'); // create template files

  const templateVariables = (0, _getInitTaskTemplateVariables.getInitTaskTemplateVariables)(settings);
  await (0, _spinner.spinnerAction)(Promise.all(settings.templates.map(([source, target]) => (0, _template.nodeTemplateAction)(argv, {
    source,
    target,
    variables: templateVariables
  }))), 'Create template files'); // npm install

  await (0, _spinner.spinnerAction)((0, _install.npmInstallAction)(argv, {
    packages: settings.libraryProduction,
    mode: 'prod'
  }), 'Install prod dependencies');
  await (0, _spinner.spinnerAction)((0, _install.npmInstallAction)(argv, {
    packages: settings.libraryDevelopment,
    mode: 'dev'
  }), 'Install dev dependencies'); // update package.json with settings

  await (0, _spinner.spinnerAction)((0, _packageUpdate.npmPackageUpdateAction)(argv, {
    settings: { ...settings.packageUpdate,
      bin: settings.packageBin,
      scripts: settings.packageScripts,
      peerDependencies: settings.packagePeerDependencies
    }
  }), 'Update the package.json'); // install package.json "prepare" command

  if (typeof settings.packageScripts.prepare === 'string') {
    await (0, _spinner.spinnerAction)((0, _exec.exec)({
      cmd: 'npm',
      args: ['run', 'prepare'],
      cwd: argv.cwd,
      log: argv.log
    }), 'Enable git hooks handling');
  }

  if (!props.noCommit && !hasGitFolder) {
    // git add
    await (0, _spinner.spinnerAction)((0, _add.gitAddAction)(argv, {
      files: ['.']
    }), 'Add files to repository'); // git commit

    await (0, _spinner.spinnerAction)((0, _commit.gitCommitAction)(argv, {
      msg: 'feat: 🐣'
    }), 'Create the initial commit');
  }
};

exports.initTask = initTask;