"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.licenseTask = void 0;

var _toolLib = require("@kettil/tool-lib");

var _chalk = require("chalk");

var _licensecheck = require("../actions/tools/licensecheck");

var _config = require("../cli/config");

var _spinner = require("../cli/spinner");

var _table = require("../cli/table");

var _exit = require("../cmd/exit");

var _licenseDisabledError = require("../errors/licenseDisabledError");

var _licenseIncompatibleError = require("../errors/licenseIncompatibleError");

var _taskHook = require("../utils/taskHook");

const notice = `the check is only a suggestion and is ${(0, _chalk.underline)('not')} legal advice`;

const licenseTask = async argv => {
  try {
    const configIgnorePackages = await (0, _config.getConfig)(argv.cwd, 'license.ignore.packages');
    const ignorePackages = (0, _toolLib.isArray)(configIgnorePackages) ? configIgnorePackages.filter(v => typeof v === 'string') : [];
    await (0, _taskHook.taskHook)(argv, {
      task: 'license',
      type: 'pre'
    });
    await (0, _spinner.spinnerAction)((0, _licensecheck.licensecheckAction)(argv, ignorePackages), `License verification (${notice})`);
    await (0, _taskHook.taskHook)(argv, {
      task: 'license',
      type: 'post'
    });
  } catch (error) {
    if (error instanceof _licenseDisabledError.LicenseDisabledError) {
      return;
    }

    if (error instanceof _licenseIncompatibleError.LicenseIncompatibleError) {
      argv.log.log(' ');
      argv.log.log((0, _table.table)(error.list));
      argv.log.log(' ');
      (0, _exit.exit)();
    }

    throw error;
  }
};

exports.licenseTask = licenseTask;