"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getNodePackageInfo = void 0;

var _path = require("path");

var _toolLib = require("@kettil/tool-lib");

var _licenseHeuristics = require("../../configs/licenseHeuristics");

var _access = require("../cmd/access");

var _exec = require("../cmd/exec");

var _readdir = require("../cmd/readdir");

var _readFile = require("../cmd/readFile");

/* eslint-disable no-restricted-syntax */

/* eslint-disable no-await-in-loop */
const regexpFilename = /^(copying|license|license-\w+|licence|licence-\w+|readme)(\.markdown|\.md|\.txt)?$/iu;

const getNodePackageInfo = async ({
  cwd,
  log
}, {
  packagePath,
  ignorePackages,
  licensePackages
}) => {
  const packageJsonPath = (0, _path.join)(packagePath, 'package.json');
  const hasPackageJson = await (0, _access.access)(packageJsonPath);

  if (!hasPackageJson) {
    // No node.js package
    return undefined;
  }

  const {
    name,
    license,
    version
  } = await (0, _readFile.readFile)(packageJsonPath, true);

  if (typeof name !== 'string') {
    throw new TypeError(`Package name is not defined (${packageJsonPath})`);
  }

  if (ignorePackages.includes(name)) {
    return undefined;
  }

  const data = {
    path: packagePath.slice(Math.max(0, cwd.length + 1)),
    version: typeof version === 'string' ? version : 'UNKNOWN',
    license: 'UNKNOWN',
    name
  }; // Manual license assignment

  const licensePackage = licensePackages[data.name];

  if ((0, _toolLib.isObject)(licensePackage) && typeof licensePackage[data.version] === 'string') {
    return { ...data,
      license: licensePackage[data.version]
    };
  } // License from the package.json


  if (typeof license === 'string') {
    return { ...data,
      license
    };
  } // License from the package.json


  if ((0, _toolLib.isObject)(license) && typeof license.type === 'string') {
    return { ...data,
      license: license.type
    };
  } // License from copying|license|readme file


  const entries = await (0, _readdir.readdir)(packagePath);
  const files = entries.filter(entry => entry.isFile() && !entry.name.startsWith('.') && regexpFilename.test(entry.name)).map(entry => entry.name).sort();

  for (const file of files) {
    const content = await (0, _readFile.readFile)((0, _path.join)(packagePath, file));

    for (const [aliasLicense, regexp] of (0, _toolLib.objectEntries)(_licenseHeuristics.licenseHeuristics)) {
      if (regexp.test(content)) {
        return { ...data,
          license: aliasLicense
        };
      }
    }
  } // License over "npm view"


  const {
    stdout: npmViewLicense
  } = await (0, _exec.exec)({
    cmd: 'npm',
    args: ['view', name, 'license'],
    log,
    cwd
  });

  if (npmViewLicense.trim() !== '') {
    return { ...data,
      license: npmViewLicense.trim()
    };
  }

  return data;
};

exports.getNodePackageInfo = getNodePackageInfo;